﻿using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Unity;
using Photoviewer.Modules.Albums.Views;

namespace Photoviewer.Modules.Albums
{
    public class AlbumModule: IModule
    {
        private readonly IUnityContainer _container;

        /// <summary>
        /// Initializes a new instance of the AlbumModule class.
        /// </summary>
        public AlbumModule(IUnityContainer container)
        {
            _container = container;
        }

        #region IModule Members

        /// <summary>
        /// Initializes the module
        /// </summary>
        public void Initialize()
        {
            InitializeTypes();
            InitializeController();
        }

        private void InitializeController()
        {
            AlbumModuleController controller = _container.Resolve<AlbumModuleController>();
            controller.Initialize();
        }

        /// <summary>
        /// Initializes additional types in the IoC container
        /// </summary>
        private void InitializeTypes()
        {
            _container.RegisterType<IAlbumsView, AlbumsView>();
            _container.RegisterType<IAlbumDetailsView, AlbumDetailsView>();
            _container.RegisterType<ICreateAlbumView, CreateAlbumView>();
        }

        #endregion
    }
}
