﻿using System.Windows;
using System.Windows.Input;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.Albums.Views
{
    /// <summary>
    /// View model for the view
    /// </summary>
    public class AlbumsViewModel : DependencyObject
    {
        #region Commands

        /// <summary>
        /// Gets or sets the command to refresh the contents of the view
        /// </summary>
        public ICommand RefreshCommand
        {
            get { return (ICommand)GetValue(RefreshCommandProperty); }
            set { SetValue(RefreshCommandProperty, value); }
        }

        // Using a DependencyProperty as the backing store for RefreshCommand.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty RefreshCommandProperty =
            DependencyProperty.Register("RefreshCommand", typeof(ICommand), typeof(AlbumsViewModel), new UIPropertyMetadata(null));
        
        #endregion

        #region Business Properties

        /// <summary>
        /// Gets or sets the selected album
        /// </summary>
        public Album SelectedAlbum
        {
            get { return (Album)GetValue(SelectedAlbumProperty); }
            set { SetValue(SelectedAlbumProperty, value); }
        }

        /// <summary>
        /// Gets or sets the albums to display
        /// </summary>
        public AlbumCollection Albums
        {
            get { return (AlbumCollection)GetValue(AlbumsProperty); }
            set { SetValue(AlbumsProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Albums.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty AlbumsProperty =
            DependencyProperty.Register("Albums", typeof(AlbumCollection), typeof(AlbumsViewModel), new UIPropertyMetadata(null));

        // Using a DependencyProperty as the backing store for SelectedAlbum.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty SelectedAlbumProperty =
            DependencyProperty.Register("SelectedAlbum", typeof(Album), typeof(AlbumsViewModel), new UIPropertyMetadata(null));
        
        #endregion
    }
}
