﻿using System;
using Microsoft.Practices.Composite.Wpf.Commands;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.Albums.Views
{
    /// <summary>
    /// Presenter for the albums view
    /// </summary>
    public class AlbumsViewPresenter
    {
        private readonly IAlbumsView _view;
        private AlbumsViewModel _model;

        public event EventHandler SelectedAlbumChanged;

        /// <summary>
        /// Initializes a new instance of the AlbumsViewPresenter class.
        /// </summary>
        /// <param name="view"></param>
        public AlbumsViewPresenter(IAlbumsView view, AlbumsViewModel model)
        {
            _view = view;
            _model = model;
        }

        #region Public methods

        /// <summary>
        /// Initializes the view
        /// </summary>
        public void Initialize()
        {
            _model = new AlbumsViewModel();
            _view.Model = _model;

            _view.SelectedAlbumChanged += View_SelectedAlbumChanged;
            _model.RefreshCommand = new DelegateCommand<object>(RefreshData);

            RefreshData(null);
        }

        

        /// <summary>
        /// Reloads the contents of the view model
        /// </summary>
        public void Refresh()
        {
            RefreshData(null);
        }

        #endregion

        #region Private methods

        /// <summary>
        /// Handles the SelectedAlbumChanged event of the view
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void View_SelectedAlbumChanged(object sender, EventArgs e)
        {
            if (SelectedAlbumChanged != null)
            {
                SelectedAlbumChanged(this, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Reloads the albums
        /// </summary>
        /// <param name="args"></param>
        private void RefreshData(object args)
        {
            _model.Albums = AlbumCollection.GetAlbums();
            _model.SelectedAlbum = _model.Albums.Count > 0 ? _model.Albums[0] : null;
        }

        #endregion
        
        #region Public properties

        /// <summary>
        /// Gets the model used by the presenter
        /// </summary>
        public AlbumsViewModel Model
        {
            get
            {
                return _model;
            }
        }

        /// <summary>
        /// Gets the view used by the presenter
        /// </summary>
        public IAlbumsView View
        {
            get
            {
                return _view;
            }
        }

        #endregion
    }
}
