﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using Photoviewer.Controls;

namespace Photoviewer.Common
{
    /// <summary>
    /// Helper class to display views as dialogs
    /// </summary>
    public static class DialogWorkspace
    {
        private static FxDialog _currentDialog;

        /// <summary>
        /// Closes the active workspace
        /// </summary>
        public static void CloseActiveWorkspace()
        {
            if(_currentDialog != null)
            {
                _currentDialog.Close();
                _currentDialog = null;
            }
        }

        /// <summary>
        /// Displays a view as a dialog
        /// </summary>
        /// <param name="view">View to display</param>
        /// <param name="options">Options for the dialog</param>
        /// <param name="validationAction">Action to execute when the dialog is closed</param>
        public static bool? ShowView(object view, DialogOptions options, Func<bool> validationAction)
        {
            FxDialog dialog = new FxDialog();
            dialog.View = view as DependencyObject;

            // Apply the dialog options if provided
            if (options != null)
            {
                dialog.ResizeMode = options.AllowResize ? ResizeMode.CanResize : ResizeMode.NoResize;
                dialog.Title = options.DialogTitle ?? "";
                dialog.ShowInTaskbar = options.ShowInTaskBar;

                if (options.HideOkCancelButtons)
                {
                    dialog.ButtonPanelVisibility = Visibility.Collapsed;
                }

                if (options.DialogSize.Width > 0 && options.DialogSize.Height > 0)
                {
                    dialog.Width = options.DialogSize.Width;
                    dialog.Height = options.DialogSize.Height;
                    dialog.SizeToContent = SizeToContent.Manual;
                }
            }

            dialog.ValidateDialog += new EventHandler<System.ComponentModel.CancelEventArgs>((sender, e) =>
            {
                e.Cancel = false;

                if (validationAction != null)
                {
                    // Validate action will return false when validation fails
                    // invert this result to cancel the close action
                    e.Cancel = !validationAction();
                }
            });

            _currentDialog = dialog;

            bool? result = dialog.ShowDialog();

            _currentDialog = null;

            return result;
        }
    }
}
