﻿using Microsoft.Practices.Composite.Events;
using Microsoft.Practices.Composite.Regions;
using Microsoft.Practices.Unity;

namespace Photoviewer.Common
{
    /// <summary>
    /// Base class for module controllers
    /// </summary>
    public abstract class ModuleController
    {
        #region Private Fields

        private readonly IUnityContainer _container;
        private readonly IRegionManager _regionManager;
        private readonly IEventAggregator _eventAggregator;

        #endregion

        #region Public Constructors

        /// <summary>
        /// Initializes a new instance of the ModuleController class.
        /// </summary>
        /// <param name="container"></param>
        public ModuleController(IUnityContainer container)
        {
            _container = container;
            _regionManager = _container.Resolve<IRegionManager>();
            _eventAggregator = _container.Resolve<IEventAggregator>();
        }

        #endregion

        #region Protected properties

        /// <summary>
        /// Gets the inversion of control container
        /// </summary>
        protected IUnityContainer Container
        {
            get { return _container; }
        }

        /// <summary>
        /// Gets the event aggregator
        /// </summary>
        protected IEventAggregator EventAggregator
        {
            get { return _eventAggregator; }
        }

        /// <summary>
        /// Gets the region manager
        /// </summary>
        protected IRegionManager RegionManager
        {
            get { return _regionManager; }
        }

        #endregion
    }
}
