﻿using System.Collections.ObjectModel;
using System.IO;

namespace Photoviewer.DataAccess.Contract
{
    /// <summary>
    /// Contract for the data provider
    /// </summary>
    public interface IPhotoDataProvider
    {
        /// <summary>
        /// Gets raw image data from disk
        /// </summary>
        /// <param name="path"></param>
        /// <returns></returns>
        Stream GetImageData(string path);

        /// <summary>
        /// Gets a single photo
        /// </summary>
        /// <param name="value"></param>
        /// <returns></returns>
        PhotoData GetPhotoByPath(string value);
        
        /// <summary>
        /// Creates new photo metadata
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        PhotoData CreatePhotoMetadata(PhotoData data);

        /// <summary>
        /// Updates photo metadata
        /// </summary>
        /// <param name="data"></param>
        /// <returns></returns>
        PhotoData UpdatePhotoMetadata(PhotoData data);

        /// <summary>
        /// Removes a photo from disk
        /// </summary>
        /// <param name="value"></param>
        void DeletePhoto(string value);

        /// <summary>
        /// Gets all photos from the specified album path
        /// </summary>
        /// <param name="path"></param>
        /// <returns></returns>
        Collection<PhotoData> GetPhotosByAlbumPath(string path);

        /// <summary>
        /// Gets all photos with the specified tag
        /// </summary>
        /// <param name="tagName"></param>
        /// <returns></returns>
        Collection<PhotoData> GetPhotosByTag(string tagName);
    }
}
