﻿using System;
using System.Runtime.Serialization;

namespace Photoviewer.DataAccess.Implementation
{
    /// <summary>
    /// Exception to indicate a problem finding the correct album
    /// </summary>
    [Serializable]
    public class AlbumNotFoundException : Exception
    {
        private readonly string _path;

        #region Constructors
        /// <summary>
        /// Serialization constructor
        /// </summary>
        /// <param name="info"></param>
        /// <param name="context"></param>
        protected AlbumNotFoundException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
            _path = info.GetString("_path");
        }

        /// <summary>
        /// Initializes a new instance of the PhotoNotFoundException class.
        /// </summary>
        /// <param name="path"></param>
        public AlbumNotFoundException(string message, string path)
            : this(message)
        {
            _path = path;
        }

        /// <summary>
        /// Constructs a new AlbumNotFoundException.
        /// </summary>
        public AlbumNotFoundException() { }
        /// <summary>
        /// Constructs a new AlbumNotFoundException.
        /// </summary>
        /// <param name="message">The exception message</param>
        public AlbumNotFoundException(string message) : base(message) { }
        /// <summary>
        /// Constructs a new AlbumNotFoundException.
        /// </summary>
        /// <param name="message">The exception message</param>
        /// <param name="innerException">The inner exception</param>
        public AlbumNotFoundException(string message, Exception innerException) : base(message, innerException) { }
        
        #endregion

        #region Public Properties

        /// <summary>
        /// Gets the path where the photo was expected
        /// </summary>
        public string Path
        {
            get
            {
                return _path;
            }
        }

        #endregion
    }
}
