﻿using System;
using System.Runtime.Serialization;

namespace Photoviewer.DataAccess.Implementation
{
    /// <summary>
    /// Exception indicating a problem finding a photo in the storage
    /// </summary>
    [Serializable]
    public class PhotoNotFoundException : Exception
    {
        private readonly string _path;

        #region Constructors

        /// <summary>
        /// Serialization constructor
        /// </summary>
        /// <param name="info"></param>
        /// <param name="context"></param>
        protected PhotoNotFoundException(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
            _path = info.GetString("_path");
        }

        /// <summary>
        /// Initializes a new instance of the PhotoNotFoundException class.
        /// </summary>
        /// <param name="path"></param>
        public PhotoNotFoundException(string message,string path)
            : this(message)
        {
            _path = path;
        }

        /// <summary>
        /// Constructs a new PhotoNotFoundException.
        /// </summary>
        public PhotoNotFoundException()
        {
            
        }

        /// <summary>
        /// Constructs a new PhotoNotFoundException.
        /// </summary>
        /// <param name="message">The exception message</param>
        public PhotoNotFoundException(string message)
            : base(message)
        {

        }

        /// <summary>
        /// Constructs a new PhotoNotFoundException.
        /// </summary>
        /// <param name="message">The exception message</param>
        /// <param name="innerException">The inner exception</param>
        public PhotoNotFoundException(string message, Exception innerException)
            : base(message, innerException)
        {

        }
        

        #endregion

        #region Public Properties

        /// <summary>
        /// Gets the path where the photo was expected
        /// </summary>
        public string Path
        {
            get
            {
                return _path;
            }
        }
        
        #endregion
    }
}
