﻿using System;
using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Globalization;
using Csla;
using Photoviewer.DataAccess.Contract;

namespace Photoviewer.DomainModel
{
    /// <summary>
    /// Contains a collection of albums
    /// </summary>
    [Serializable]
    public class AlbumCollection : ReadOnlyListBase<AlbumCollection, Album>
    {
        #region Factory Methods

        /// <summary>
        /// Retrieves all albums
        /// </summary>
        /// <returns></returns>
        public static AlbumCollection GetAlbums()
        {
            return DataPortal.Fetch<AlbumCollection>();
        }

        /// <summary>
        /// Initializes a new instance of <see cref="AlbumCollection"/>
        /// </summary>
        private AlbumCollection()
        {  /* Require use of factory methods */ }

        #endregion

        #region Data access methods

        /// <summary>
        /// Fetches the albums
        /// </summary>
        /// <param name="criteria"></param>
        private void DataPortal_Fetch()
        {
            var provider = ModelContext.Container.Resolve<IAlbumDataProvider>();
            Collection<AlbumData> data = provider.GetAlbums();

            IsReadOnly = false;
            RaiseListChangedEvents = false;

            Trace.WriteLine(String.Format(CultureInfo.InvariantCulture, "Loaded {0} albums",data.Count));

            foreach (AlbumData album in data)
            {
                Add(Album.GetAlbum(album));
            }

            IsReadOnly = true;
            RaiseListChangedEvents = true;
        }
        
        #endregion
    }
}
