﻿using System.ComponentModel;

namespace Photoviewer.DomainModel
{
    public class Tag: INotifyPropertyChanged
    {
        #region Private fields

        private int _occurrences;
        private string _name;
        private double _deviation;

        #endregion

        #region Public properties

        /// <summary>
        /// Gets or sets the name of the tag
        /// </summary>
        public string Name
        {
            get
            {
                return _name;
            }
            set
            {
                _name = value;
                OnPropertyChanged(new PropertyChangedEventArgs("Name"));
            }
        }

        /// <summary>
        /// Gets or sets the number of occurrences of the tag in the cloud
        /// </summary>
        public int Occurrences
        {
            get
            {
                return _occurrences;
            }
            set
            {
                _occurrences = value;
                OnPropertyChanged(new PropertyChangedEventArgs("Occurrences"));
            }
        }

        /// <summary>
        /// Gets or sets the deviation from average occurrences in the tag cloud
        /// </summary>
        public double Deviation
        {
            get
            {
                return _deviation;
            }
            set
            {
                _deviation = value;
                OnPropertyChanged(new PropertyChangedEventArgs("Deviation"));
            }
        }
        
        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #region OnPropertyChanged
        /// <summary>
        /// Triggers the PropertyChanged event.
        /// </summary>
        public virtual void OnPropertyChanged(PropertyChangedEventArgs ea)
        {
            if (PropertyChanged != null)
                PropertyChanged(null/*this*/, ea);
        }
        #endregion

        #endregion
    }
}
