﻿using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Unity;
using Photoviewer.Modules.Photos.Views;

namespace Photoviewer.Modules.Photos
{
    public class PhotoModule: IModule
    {
        private readonly IUnityContainer _container;

        /// <summary>
        /// Initializes a new instance of the PhotoModule class.
        /// </summary>
        /// <param name="container"></param>
        public PhotoModule(IUnityContainer container)
        {
            _container = container;
        }

        #region IModule Members

        /// <summary>
        /// Initializes the module
        /// </summary>
        public void Initialize()
        {
            InitializeTypes();
            InitializeController();
        }
        
        private void InitializeTypes()
        {
            _container.RegisterType<IPhotosView, PhotosView>();
            _container.RegisterType<IPhotoDetailsView, PhotoDetailsView>();
            _container.RegisterType<IPhotoSummaryView, PhotoSummaryView>();
            _container.RegisterType<ICollageView, CollageView>();
        }

        private void InitializeController()
        {
            PhotoModuleController controller = _container.Resolve<PhotoModuleController>();
            controller.Initialize();
        }
        #endregion
    }
}
