﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.Photos.Views
{
    /// <summary>
    /// Model that contains extra information required to generate the photo collage
    /// </summary>
    public class CollagePhoto : PhotoViewModel
    {
        #region Private fields

        private double _left;
        private double _top;
        private double _angle;

        #endregion

        #region Public constructors

        /// <summary>
        /// Initializes a new instance of CollagePhoto
        /// </summary>
        /// <param name="original"></param>
        public CollagePhoto(Photo original)
            : base(original)
        {
        }

        #endregion

        #region Public properties

        /// <summary>
        /// Gets the angle of rotation for the photo
        /// </summary>
        public double Angle
        {
            get { return _angle; }
            set
            {
                _angle = value;

                OnPropertyChanged(
                    new PropertyChangedEventArgs("Angle"));
            }
        }

        /// <summary>
        /// Gets or sets the left offset of the photo on the collage
        /// </summary>
        public double Left
        {
            get { return _left; }
            set
            {
                _left = value;

                OnPropertyChanged(
                    new PropertyChangedEventArgs("Left"));
            }
        }

        /// <summary>
        /// Gets or sets the top offset of the photo on the collage
        /// </summary>
        public double Top
        {
            get { return _top; }
            set
            {
                _top = value;

                OnPropertyChanged(
                    new PropertyChangedEventArgs("Top"));
            }
        }

        #endregion

    }
}
