﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Photoviewer.Controls;
using System.Diagnostics;

namespace Photoviewer.Modules.Photos.Views
{
    /// <summary>
    /// Interaction logic for CollageView.xaml
    /// </summary>
    public partial class CollageView : UserControl, ICollageView
    {
        public CollageView()
        {
            InitializeComponent();
        }

        public string Title
        {
            get { return "Photo collage"; }
        }

        #region ICollageView Members

        public event EventHandler RegenerationRequested;
        public event EventHandler PhotoDetailsRequested;
        public event EventHandler SelectedPhotoChanged;

        public CollageViewPresenter Presenter
        {
            get { return this.DataContext as CollageViewPresenter; }
            set { this.DataContext = value; }
        }

        public Size ViewportSize
        {
            get { return new Size(this.ActualWidth,this.ActualHeight); }
        }

        #endregion

        private void OnRegenerateViewClick(object sender, RoutedEventArgs e)
        {
            if (RegenerationRequested != null)
                RegenerationRequested(this, EventArgs.Empty);
        }

        #region Listbox event handling logic
        
        private void ListBox_MouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
            if (Presenter.SelectedPhoto != null && PhotoDetailsRequested != null)
            {
                PhotoDetailsRequested(this, EventArgs.Empty);
            }
        }

        private void ListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (Presenter.SelectedPhoto != null && SelectedPhotoChanged != null)
            {
                SelectedPhotoChanged(this, EventArgs.Empty);
            }
        } 

        #endregion

        #region Item drag and drop logic

        private bool _isDraggingItem;
        private Point _newLocation;
        private Point _grabLocation;
        private DragAdorner _adorner;

        private void OnItemMouseDown(object sender, MouseButtonEventArgs e)
        {
            CollagePhoto photo = ((Grid)sender).DataContext as CollagePhoto;

            if (photo != null)
            {
                _adorner = new DragAdorner((UIElement)sender);
                AdornerLayer.GetAdornerLayer(this).Add(_adorner);

                ((IInputElement)sender).CaptureMouse();

                _isDraggingItem = true;
                _grabLocation = e.GetPosition((Grid)sender);
            }
        }

        private void OnItemMouseUp(object sender, MouseButtonEventArgs e)
        {
            CollagePhoto photo = ((Grid)sender).DataContext as CollagePhoto;

            if (photo != null)
            {
                ((IInputElement)sender).ReleaseMouseCapture();

                Point translatedPoint = this.PointFromScreen(_newLocation);

                photo.Left = translatedPoint.X;
                photo.Top = translatedPoint.Y;

                AdornerLayer.GetAdornerLayer(this).Remove(_adorner);
            }
        }

        private void OnItemMouseMove(object sender, MouseEventArgs e)
        {
            CollagePhoto photo = ((Grid)sender).DataContext as CollagePhoto;

            if (photo != null && e.LeftButton == MouseButtonState.Pressed)
            {
                Point position = e.GetPosition((Grid)sender);
                Point adornerPosition = Mouse.GetPosition(this);

                Trace.WriteLine(position);

                ((IInputElement)sender).CaptureMouse();

                Point screenLocation = ((Grid)sender).PointToScreen(position);
                _newLocation = new Point(screenLocation.X - _grabLocation.X, screenLocation.Y - _grabLocation.Y);

                _adorner.Location = new Point(position.X - _grabLocation.X,position.Y - _grabLocation.Y);
            }
        } 

        #endregion
    }
}
