﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections.ObjectModel;
using Photoviewer.DomainModel;
using System.Diagnostics;

namespace Photoviewer.Modules.Photos.Views
{
    /// <summary>
    /// Presenter for the photo collage view
    /// </summary>
    public class CollageViewPresenter: IPhotoSelector
    {
        private ICollageView _view;
        private Album _model;
        private ObservableCollection<CollagePhoto> _photos;
        private Random _randomizer;
        private PhotoViewModel _selectedPhoto;

        public event EventHandler PhotoDetailsRequested;
        public event EventHandler SelectedPhotoChanged;

        /// <summary>
        /// Initializes the presenter
        /// </summary>
        /// <param name="view"></param>
        public CollageViewPresenter(ICollageView view)
        {
            _photos = new ObservableCollection<CollagePhoto>();
            _randomizer = new Random(Environment.TickCount);

            _view = view;
            _view.Presenter = this;

            _view.PhotoDetailsRequested += new EventHandler(OnPhotoDetailsRequested);
            _view.RegenerationRequested += new EventHandler(OnRegenerationRequest);
            _view.SelectedPhotoChanged += new EventHandler(OnSelectedPhotoChanged);
        }

        

        #region Public methods

        public void ShowAlbumContents(Album album)
        {
            _model = album;
            GenerateCollage();
        }

        #endregion

        #region Private methods

        private void OnPhotoDetailsRequested(object sender, EventArgs e)
        {
            if (PhotoDetailsRequested != null)
                PhotoDetailsRequested(this, EventArgs.Empty);
        }

        private void OnSelectedPhotoChanged(object sender, EventArgs e)
        {
            if(SelectedPhotoChanged != null)
                SelectedPhotoChanged(this, EventArgs.Empty);
        }

        private void OnRegenerationRequest(object sender, EventArgs e)
        {
            GenerateCollage();
        }

        private void GenerateCollage()
        {
            _photos.Clear();

            foreach (Photo photo in _model.Photos)
            {
                var collagedPhoto = new CollagePhoto(photo);

                collagedPhoto.Angle = _randomizer.Next(-15, 15);

                Trace.WriteLine("Rotation generated: " + collagedPhoto.Angle);

                collagedPhoto.Left = _randomizer.Next(10, Math.Max((int)_view.ViewportSize.Width - 170, 200));
                collagedPhoto.Top = _randomizer.Next(10, Math.Max((int)_view.ViewportSize.Height - 110, 200));

                _photos.Add(collagedPhoto);
            }
        }

        #endregion

        #region Public properties

        /// <summary>
        /// Gets the view that is attached to the presenter
        /// </summary>
        public ICollageView View
        {
            get { return _view; }
        }

        public ObservableCollection<CollagePhoto> Photos
        {
            get { return _photos; }
        }

        #endregion


        #region IPhotoSelector Members

        public PhotoViewModel SelectedPhoto
        {
            get { return _selectedPhoto; }
            set { _selectedPhoto = value; }
        }

        #endregion
    }
}
