﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.Photos.Views
{
    public class AlbumViewModel: INotifyPropertyChanged
    {
        private readonly ObservableCollection<PhotoViewModel> _photos;
        private readonly Album _original;
        private PhotoViewModel _selectedPhoto;

        /// <summary>
        /// Initializes a new instance of the PhotosViewModel class.
        /// </summary>
        public AlbumViewModel(Album original)
        {
            _original = original;
            _photos = new ObservableCollection<PhotoViewModel>();

            foreach (Photo picture in original.Photos)
            {
                PhotoViewModel pictureView = new PhotoViewModel(picture);
                _photos.Add(pictureView);
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #region OnPropertyChanged
        /// <summary>
        /// Triggers the PropertyChanged event.
        /// </summary>
        public virtual void OnPropertyChanged(PropertyChangedEventArgs ea)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, ea);
        }
        #endregion

        #endregion

        #region Public properties

        /// <summary>
        /// Gets the photos that need to be displayed
        /// </summary>
        public ObservableCollection<PhotoViewModel> Photos
        {
            get { return _photos; }
        }

        /// <summary>
        /// Gets or sets the selected photo
        /// </summary>
        public PhotoViewModel SelectedPhoto
        {
            get
            {
                return _selectedPhoto;
            }
            set
            {
                _selectedPhoto = value;
                OnPropertyChanged(new PropertyChangedEventArgs("SelectedPhoto"));
            }
        }

        /// <summary>
        /// Gets or sets the title of the album
        /// </summary>
        public string Title
        {
            get
            {
                return _original.Title;
            }
            set
            {
                _original.Title = value;
                OnPropertyChanged(new PropertyChangedEventArgs("Title"));
            }
        }

        #endregion

        #region Overrides

        public override bool Equals(object obj)
        {
            AlbumViewModel other = obj as AlbumViewModel;

            if (other != null)
            {
                return other._original.Equals(_original);
            }

            return false;
        }

        public override int GetHashCode()
        {
            return _original.GetHashCode();
        }
        
        #endregion
    }

}
