﻿using System;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.Photos.Views
{
    public class PhotosViewPresenter: IPhotoSelector
    {
        private readonly IPhotosView _view;
        private AlbumViewModel _model;

        public event EventHandler PhotoDetailsRequested;
        public event EventHandler SelectedPhotoChanged;

        /// <summary>
        /// Initializes a new instance of the PhotosPresenter class.
        /// </summary>
        /// <param name="view"></param>
        public PhotosViewPresenter(IPhotosView view)
        {
            _view = view;

            _view.PhotoDetailsRequested += OnPhotoDetailsRequested;
            _view.SelectedPhotoChanged += OnSelectedPhotoChanged;
        }

        

        #region Private methods

        /// <summary>
        /// Handles the SelectedPhotoChanged event of the view
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void OnSelectedPhotoChanged(object sender, EventArgs e)
        {
            if (SelectedPhotoChanged != null)
            {
                SelectedPhotoChanged(this, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Handles the PhotoDetailsRequested event of the view
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void OnPhotoDetailsRequested(object sender, EventArgs e)
        {
            if (PhotoDetailsRequested != null)
            {
                PhotoDetailsRequested(this, EventArgs.Empty);
            }
        }

        #endregion

        #region Public methods

        /// <summary>
        /// Reloads the view data from the specified album
        /// </summary>
        /// <param name="selectedAlbum"></param>
        public void ShowAlbumContents(Album selectedAlbum)
        {
            _model = new AlbumViewModel(selectedAlbum);
            _view.Model = _model;
        }

        #endregion

        #region Public properties

        public IPhotosView View
        {
            get
            {
                return _view;
            }
        }

        public AlbumViewModel Model
        {
            get
            {
                return _model;
            }
        }
        #endregion

        #region IPhotoSelector Members

        public PhotoViewModel SelectedPhoto
        {
            get { return _model.SelectedPhoto; }
        }

        #endregion
    }
}
