﻿using System.Configuration;
using System.IO;
using System.Windows;
using Microsoft.Practices.Composite.Modularity;
using Microsoft.Practices.Composite.UnityExtensions;
using Photoviewer.DataAccess.Contract;
using Photoviewer.DataAccess.Implementation;
using Photoviewer.DomainModel;
using Photoviewer.Modules.Albums;
using Photoviewer.Modules.Photos;
using Photoviewer.Modules.TagCloud;
using Photoviewer.Modules.Printing;

namespace Photoviewer
{
    /// <summary>
    /// Bootstrapper for the application
    /// </summary>
    public class Bootstrapper: UnityBootstrapper
    {
        /// <summary>
        /// Creates the shell for the application
        /// </summary>
        /// <returns></returns>
        protected override DependencyObject CreateShell()
        {
            Shell mainWindow = Container.Resolve<Shell>();
            mainWindow.Show();

            return mainWindow;
        }

        /// <summary>
        /// Gets the application module enumerator
        /// </summary>
        /// <returns></returns>
        protected override IModuleEnumerator GetModuleEnumerator()
        {
            return new StaticModuleEnumerator()
                .AddModule(typeof(PhotoModule))
                .AddModule(typeof(AlbumModule))
                .AddModule(typeof(TagsModule))
                .AddModule(typeof(PrintModule));
        }

        /// <summary>
        /// Configures common services for the application
        /// </summary>
        protected override void ConfigureContainer()
        {
            base.ConfigureContainer();

            string albumBasePath = ConfigurationManager.AppSettings["AlbumsBasePath"];

            PhotoDataProvider provider = new PhotoDataProvider(albumBasePath);
            AlbumDataProvider albumProvider = new AlbumDataProvider(albumBasePath);

            Container.RegisterInstance<IPhotoDataProvider>(provider);
            Container.RegisterInstance<IAlbumDataProvider>(albumProvider);

            ModelContext.Initialize(Container);
        }
    }
}
