﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Photoviewer.DomainModel;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Shapes;

namespace Photoviewer.Modules.Printing
{

    /// <summary>
    /// Wrapper around the photo domain model
    /// that adds properties and methods required to print the photo
    /// </summary>
    public class PrintablePhoto
    {
        #region Private fields
        
        private Photo _original;
        private System.Drawing.Image _image;

        #endregion
        
        #region Public constructors
        
        /// <summary>
        /// Initializes a new instance of PrintablePhoto
        /// </summary>
        /// <param name="original"></param>
        public PrintablePhoto(Photo original)
        {
            this._original = original;
            this._image = System.Drawing.Image.FromStream(_original.Load());
        } 

        #endregion

        #region Public properties

        /// <summary>
        /// Gets the raw image data of the photo
        /// </summary>
        public ImageSource ImageData
        {
            get
            {
                BitmapImage fullImage = new BitmapImage();

                fullImage.BeginInit();

                fullImage.StreamSource = _original.Load();

                fullImage.EndInit();
                fullImage.Freeze();

                return fullImage;
            }
        }

        /// <summary>
        /// Gets the width of the image
        /// </summary>
        public int Width
        {
            get { return _image.Width; }
        }

        /// <summary>
        /// Gets the height of the image
        /// </summary>
        public int Height
        {
            get { return _image.Height; }
        }

        /// <summary>
        /// Gets the orientation of the image
        /// </summary>
        public Orientation Orientation
        {
            get { return Width > Height ? Orientation.Horizontal : Orientation.Vertical; }
        } 

        #endregion
    }
}
