﻿using System;
using Microsoft.Practices.Composite.Events;
using Photoviewer.Common;
using Photoviewer.DomainModel;

namespace Photoviewer.Modules.TagCloud.Views
{
    public class TagCloudPresenter
    {
        private readonly ITagCloudView _view;
        private DomainModel.TagCloud _model;
        private readonly IEventAggregator _eventAggregator;

        /// <summary>
        /// Initializes a new instance of the TagCloudPresenter class.
        /// </summary>
        public TagCloudPresenter(ITagCloudView view, IEventAggregator eventAggregator)
        {
            _model = new DomainModel.TagCloud();
            _eventAggregator = eventAggregator;

            _model.Refresh();

            _view = view;
            _view.UpdateRequested += OnUpdateRequested;
            _view.TagSelected += OnTagSelected;

            _view.Model = _model;
        }

        void OnTagSelected(object sender, TagSelectedEventArgs e)
        {
            ActiveAlbumChangedEvent @event = _eventAggregator.GetEvent<ActiveAlbumChangedEvent>();
            @event.Publish(Album.GetTagsAlbum(e.TagName));
        }

        void OnUpdateRequested(object sender, EventArgs e)
        {
            _view.Model = null;

            _model = new DomainModel.TagCloud();
            _model.Refresh();

            _view.Model = _model;
        }

        /// <summary>
        /// Gets the view associated with the presenter
        /// </summary>
        public ITagCloudView View
        {
            get { return _view; }
        }
    }
}
