﻿using System.Collections.ObjectModel;
using Microsoft.Practices.Unity;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Photoviewer.DataAccess.Contract;
using Rhino.Mocks;

namespace Photoviewer.DomainModel.Fixtures
{
    /// <summary>
    /// Test fixture for the album collection class
    /// </summary>
    [TestClass]
    public class AlbumCollectionFixture
    {
        /// <summary>
        /// Gets all albums
        /// </summary>
        [TestMethod]
        public void TestGetAlbums()
        {
            MockRepository repository = new MockRepository();
            IAlbumDataProvider provider = null;
            IUnityContainer container = new UnityContainer();

            AlbumData savedData = new AlbumData
                                      {
                Path = "C:\\test",
                Title = "test"
            };

            using (repository.Record())
            {
                provider = repository.StrictMock<IAlbumDataProvider>();
                Expect.Call(provider.GetAlbums()).Return(new Collection<AlbumData>
                                                             {
                    savedData
                });
            }

            container.RegisterInstance(provider);
            ModelContext.Initialize(container);

            AlbumCollection albums = AlbumCollection.GetAlbums();

            repository.VerifyAll();
        }
    }
}
