﻿using System.Collections.ObjectModel;
using Microsoft.Practices.Unity;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Photoviewer.DataAccess.Contract;
using Rhino.Mocks;

namespace Photoviewer.DomainModel.Fixtures
{
    /// <summary>
    /// Fixture to check the business logic of the photo collection class
    /// </summary>
    [TestClass]
    public class PhotoCollectionFixture
    {
        /// <summary>
        /// Gets a set of photos that are part of an album
        /// </summary>
        [TestMethod]
        public void GetPhotosByAlbum()
        {
            MockRepository repository = new MockRepository();
            IAlbumDataProvider albumProvider = null;
            IPhotoDataProvider photoProvider = null;
            IUnityContainer container = new UnityContainer();

            AlbumData savedData = new AlbumData
                                      {
                Path = "C:\\test",
                Title = "test"
            };

            PhotoData photoData = new PhotoData
                                      {
                Title = "Test",
                Path = "C:\\test\\test.jpg",
                AlbumPath = "C:\\test",
                Tags = new Collection<string>
                           {
                    "Test 1",
                    "Test 2"
                }
            };

            using (repository.Record())
            {
                albumProvider = repository.StrictMock<IAlbumDataProvider>();
                photoProvider = repository.StrictMock<IPhotoDataProvider>();
                Expect.Call(albumProvider.GetAlbumByPath("C:\\test")).Return(savedData);
                Expect.Call(photoProvider.GetPhotosByAlbumPath("C:\\test")).Return(new Collection<PhotoData> { photoData });
            }

            container.RegisterInstance(albumProvider);
            container.RegisterInstance(photoProvider);

            ModelContext.Initialize(container);

            Album album = Album.GetAlbum("C:\\test");
            PhotoCollection photos = PhotoCollection.GetPhotos(album);

            Assert.AreNotEqual(0, photos.Count);

            repository.VerifyAll();
        }
    }
}
